package pl.edu.pwr.example;

import java.io.BufferedOutputStream;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import static java.nio.file.StandardOpenOption.*;

/**
 * Istniej dwa (trzy) pakiety klas, ktre w jzyku Java stosowane s do obsugi
 * operacji wejcia/wyjcia. S to: java.io oraz java.nio (ten drugi udostpnia
 * ju cz z funkcji NIO.2 Zobacz:
 * https://docs.oracle.com/javase/8/docs/technotes/guides/io/index.html
 * https://docs.oracle.com/en/java/javase/11/docs/api/java.base/java/io/package-summary.html
 * https://docs.oracle.com/en/java/javase/11/docs/api/java.base/java/nio/package-summary.html
 * 
 * @author tkubik
 *
 */

public class Encoder {
	private int key = Integer.MAX_VALUE;

	public int getKey() {
		return key;
	}

	public void setKey(int key) {
		this.key = key;
	}

	public void encode(String filenameIn, String fileNameOut) {

		Path inFile = Paths.get(filenameIn);
		Path outFile = Paths.get(fileNameOut);

		InputStream is = null;
		OutputStream os = null;
		try {

			is = new FileInputStream(inFile.toFile());
			os = new FileOutputStream(outFile.toFile());
			/*
			 * alternatywnie:
			 * 
			 * InputStream is = new FileInputStream(filenameIn); 
			 * OutputStream os = new FileOutputStream(fileNameOut);
			 */

			int c;
			while ((c = is.read()) != -1) {
				os.write(c ^ key);
			}

		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (is != null) {
					is.close();
				}
				if (os != null) {
					os.close();
				}
			} catch (IOException e) {
				e.printStackTrace();
			}
		}

	}

	public void greet() {
		System.out.println("Hello from encoder");
	}

	public static void main(String ... args) {
		// Utworzenie pliku zawierajcego dany tekst
		// Kodowanie z pliku do pliku 
		// Ponowne kodowanie z pliku do pliku
		String s = "Hello World! ";
	    byte data[] = s.getBytes();
	    Path p = Paths.get("logFileIn.txt");

	    try (OutputStream out = new BufferedOutputStream(	
	      Files.newOutputStream(p, CREATE, TRUNCATE_EXISTING ))) {
	      out.write(data, 0, data.length);
	    } catch (IOException x) {
	      System.err.println(x);
	    }

	    Encoder e = new Encoder();
	    e.setKey(2);
	    e.encode("logFileIn.txt", "logFileOut.txt");
	    e.encode("logFileOut.txt", "logFileIn1.txt");
	    
	    
	}
}
